@@ -454,8 +454,69 @@ class Insight_Definition:
         return data_id
 
 
+    def add_join_to_qc(self, qc_id, dataset_slug, fields, type:str):
+
+        new_qc = self.create_qc(dataset_slug, fields)
+
+        url = self.smart_insight_url+"composed_queries/{}".format(qc_id)
+
+        body = {
+            "smartQueryId": new_qc["id"]
+        }
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        response = r.json()
+
+        qc = self.get_qc(qc_id)
+
+        right_fields = qc["qcSettings"]["fields"]
+        left_fields = new_qc[fields]
+        joinable_fields = response["joinedSmartQuery"]["joinableFields"]
+
+        body = {
+            "smartQueryId": new_qc["id"],
+            "joinType": type.upper(),
+            "leftFields": left_fields,
+            "rightFields": right_fields,
+            "dataset": {
+                "id": new_qc["datasets"][0]["id"],
+                "slug": dataset_slug
+            },
+            "joinableFields": joinable_fields
+        }
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        response = r.json()
+
+
+
+    def get_qc(self, qc_id):
+        for component in self.components:
+            if component["id"].startswith("qcomp"):
+                if component["settings"]["qc"] == qc_id:
+                    return component
+
     def add_query_composer(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
-        qc_id = self.create_qc(dataset_slug, fields, filters, sorted_by, dataset_id, limit, offset, pivot)
+        qc_id = self.create_qc(dataset_slug, fields, filters, sorted_by, dataset_id, limit, offset, pivot)["id"]
         position = (len(self.components))
         qc_post_url = self.smart_insight_url + "/definitions/" + self.definition_id + "/query_composers"
 
@@ -471,6 +532,10 @@ class Insight_Definition:
         response.raise_for_status()
         r = response.json()
         self.components = r["components"]
+        return {
+            "qc_id": qc_id,
+            "component_id": r["components"][position]["id"]
+        }
 
 
     def create_qc(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
@@ -529,10 +594,8 @@ class Insight_Definition:
         headers = {"Authorization": "Bearer" + " " + self._token}
         response = s.post(url=url, json=body, headers=headers)
         response.raise_for_status()
-        print(response.json())
-        qc_id = response.json()["id"]
 
-        return qc_id
+        return response.json()
 
     def get_component(self, component_id):
         for component in self.components:
@@ -542,7 +605,7 @@ class Insight_Definition:
 
     def add_query_composer_to_data_component(self, data_id, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
 
-        qc_id = self.create_qc(dataset_slug, fields, filters, sorted_by, dataset_id, limit, offset, pivot)
+        qc_id = self.create_qc(dataset_slug, fields, filters, sorted_by, dataset_id, limit, offset, pivot)["id"]
         name = self.get_component(data_id)["settings"]["name"]
         variable_name = self.get_component(data_id)["settings"]["variableName"]
         body = {
